@@ -6,7 +6,7 @@ use Exporter::Easy ( OK => [ qw/ratchet clank/ ] );
 use Data::Munge qw(rec);
 use Scalar::Util qw(refaddr);
 
-our $VERSION = '0.004';
+our $VERSION = '0.005';
 
 # ABSTRACT: Mocking helper that swaps out implementations automatically
 
@@ -85,11 +85,11 @@ Test::Ratchet - Mocking helper that swaps out implementations automatically
 
 =head1 VERSION
 
-version 0.004
+version 0.005
 
 =head1 SYNOPSIS
 
-    use Test::Ratchet;
+    use Test::Ratchet qw(ratchet clank);
     use Test::MockModule;
     use Test::More;
 
@@ -99,6 +99,9 @@ version 0.004
     $mock->mock( magic_method => ratchet(
         \&first_implementation,
         \&second_implementation,
+
+        # A clank *must* be run, or the test fails!
+        clank \&third_implementation,
     ));
 
     # In reality, you will have no control over the use of this object - which
@@ -109,6 +112,11 @@ version 0.004
     $obj->magic_method('foo'); # Returns { something => 'relevant' }
     $obj->magic_method('bar'); # Returns { something => 'else' }
 
+    # This test will fail! magic_method was only run twice, but there are three
+    # implementations - and the third one is a clank! Failing to run a clank
+    # causes a test failure.
+    done_testing;
+
     sub first_implementation {
         my $self = shift;
         my $arg1 = shift;
@@ -127,6 +135,16 @@ version 0.004
         return { something => 'else' }
     }
 
+
+    sub third_implementation {
+        my $self = shift;
+        my $arg1 = shift;
+
+        is $arg1, "zip", "Third call passed zip to magic_method";
+
+        return { something => 'different' }
+    }
+
 =head1 DESCRIPTION
 
 Testing sucks, especially when you have to deal with third-party code,
@@ -184,7 +202,20 @@ before it goes out of scope. You can use it in your ratchet, or independently.
         \&might_run
     );
 
-To keep the interface simple the test failure uses a generic message.
+To keep the interface simple the test failure uses a generic message that tells
+you as best as it can the script and line number at which the clank appears.
+
+I recommend that you ensure your clank goes out of scope before you end your
+test suite, so that you don't accidentally output your test summary before it
+has a chance to fail.
+
+    {
+        my $mock = Test::MockModule->new(...);
+        $mock->mock('method', clank sub { ... });
+        ... tests ...
+    }
+
+    done_testing;
 
 =head1 AUTHOR
 
